@@ -1,8 +1,9 @@
 import argparse
-from datetime import datetime
+import json
 import os
 import spotipy
-from spotipy.oauth2 import SpotifyOAuth
+
+from datetime import datetime
 
 
 class SpotibarClient():
@@ -12,9 +13,24 @@ class SpotibarClient():
         TODO: Add args/kwargs here.
         '''
         self.scope = "playlist-read-private playlist-modify-private user-read-playback-state user-modify-playback-state playlist-modify-public"
-        self.client_id = os.environ['SPOTIBAR_CLIENT_ID']
-        self.client_secret = os.environ['SPOTIBAR_CLIENT_SECRET']
+
+        try:
+            with open(os.path.expanduser("~") + "/.spotibar_config.json") as fh:
+                config = json.load(fh)
+
+                self.client_id = config['client_id']
+                self.client_secret = config['client_secret']
+        except Exception as e:
+            print("Problem with your ~/.spotibar_config.json!")
+            print(e)
+
         self.redirect_uri = "http://127.0.0.1"
+        self.cache_dir = os.path.expanduser("~") + "/.spotibar_cache"
+
+        if not os.path.exists(self.cache_dir):
+            os.makedirs(self.cache_dir)
+
+        self.cache_file = "auth_cache"
 
         self.client = self.get_client()
 
@@ -26,12 +42,12 @@ class SpotibarClient():
         Example: https://developer.spotify.com/documentation/general/guides/scopes/#playlist-modify-private
         '''
         return spotipy.Spotify(
-            auth_manager=SpotifyOAuth(
+            auth_manager=spotipy.oauth2.SpotifyOAuth(
                 scope=self.scope,
                 client_id=self.client_id,
                 client_secret=self.client_secret,
                 redirect_uri=self.redirect_uri,
-                cache_path="~/.cache/spotibar_cache"
+                cache_path=f"{self.cache_dir}/{self.cache_file}"
             )
         )
 
@@ -111,7 +127,7 @@ class SpotibarClient():
                 ]
             )
 
-            return f"Currently Playing: {current_track_name} by {current_artist_name}"
+            return f"{current_track_name} by {current_artist_name}"
         except Exception:
             return ""
 
